@@ -109,7 +109,7 @@ struct _CajaUndoStackManagerPrivate
  ***************************************************************** */
 enum
 {
-  PROP_UNDOSTACK_MANAGER_0, PROP_UNDO_LEVELS, PROP_CONFIRM_DELETE
+  PROP_UNDOSTACK_MANAGER_0, PROP_UNDO_LEVELS
 };
 
 static void caja_undostack_manager_set_property (GObject * object,
@@ -212,7 +212,6 @@ static void
 caja_undostack_manager_class_init (CajaUndoStackManagerClass * klass)
 {
   GParamSpec *undo_levels;
-  GParamSpec *confirm_delete;
   GObjectClass *g_object_class;
 
   /* Create properties */
@@ -220,11 +219,6 @@ caja_undostack_manager_class_init (CajaUndoStackManagerClass * klass)
       "Number of undo levels to be stored",
       1, UINT_MAX, 30, G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
 
-  confirm_delete =
-      g_param_spec_boolean ("confirm-delete", "confirm delete",
-      "Always confirm file deletion", FALSE,
-      G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
-
   /* Set properties get/set methods */
   g_object_class = G_OBJECT_CLASS (klass);
 
@@ -235,9 +229,6 @@ caja_undostack_manager_class_init (CajaUndoStackManagerClass * klass)
   g_object_class_install_property (g_object_class, PROP_UNDO_LEVELS,
       undo_levels);
 
-  g_object_class_install_property (g_object_class, PROP_CONFIRM_DELETE,
-      confirm_delete);
-
   /* The UI menu needs to update its status */
   g_signal_new ("request-menu-update",
       G_TYPE_FROM_CLASS (klass),
@@ -265,7 +256,6 @@ caja_undostack_manager_init (CajaUndoStackManager * self)
   priv->index = 0;
   priv->dispose_has_run = FALSE;
   priv->undo_redo_flag = FALSE;
-  priv->confirm_delete = FALSE;
 }
 
 static void
@@ -320,9 +310,6 @@ caja_undostack_manager_set_property (GObject * object, guint prop_id,
         do_menu_update (manager);
       }
       break;
-    case PROP_CONFIRM_DELETE:
-      priv->confirm_delete = g_value_get_boolean (value);
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -423,7 +410,7 @@ caja_undostack_manager_redo (CajaUndoStackManager * manager,
         uris = construct_gfile_list (action->sources, action->src_dir);
         caja_file_operations_copy (uris, NULL,
             action->dest_dir, NULL, undo_redo_done_transfer_callback, action);
-    	g_list_free_full (uris, g_object_unref);
+        g_list_free_full (uris, g_object_unref);
         break;
       }
       case CAJA_UNDOSTACK_CREATEFILEFROMTEMPLATE:
@@ -614,25 +601,11 @@ caja_undostack_manager_undo (CajaUndoStackManager * manager,
           uris = construct_gfile_list (action->destinations, action->dest_dir);
           uris = g_list_reverse (uris); // Deleting must be done in reverse
         }
-        if (priv->confirm_delete) {
-          caja_file_operations_delete (uris, NULL,
-              undo_redo_done_delete_callback, action);
-    	  g_list_free_full (uris, g_object_unref);
-        } else {
-          /* We skip the confirmation message
-           */
-          GList *f;
-          for (f = uris; f != NULL; f = f->next) {
-            char *name;
-            name = g_file_get_uri (f->data);
-            g_free (name);
-            g_file_delete (f->data, NULL, NULL);
-            g_object_unref (f->data);
-          }
-          g_list_free (uris);
-          /* Here we must do what's necessary for the callback */
-          undo_redo_done_transfer_callback (NULL, action);
-        }
+
+        caja_file_operations_delete (uris, NULL,
+            undo_redo_done_delete_callback, action);
+    	g_list_free_full (uris, g_object_unref);
+ 
         break;
       case CAJA_UNDOSTACK_RESTOREFROMTRASH:
         uris = construct_gfile_list (action->destinations, action->dest_dir);
