@@ -23,29 +23,28 @@
 */
 
 #include <config.h>
-
-#include "caja-file-management-properties.h"
-
 #include <string.h>
 #include <time.h>
+
 #include <gtk/gtk.h>
 #include <gio/gio.h>
-
 #include <glib/gi18n.h>
 #include <cairo-gobject.h>
 
 #include <eel/eel-glib-extensions.h>
+#include <eel/eel-gtk-extensions.h>
 
 #include <libcaja-private/caja-column-chooser.h>
 #include <libcaja-private/caja-column-utilities.h>
 #include <libcaja-private/caja-extensions.h>
 #include <libcaja-private/caja-global-preferences.h>
 #include <libcaja-private/caja-module.h>
-
 #include <libcaja-private/caja-autorun.h>
 
 #include <libcaja-extension/caja-configurable.h>
 
+#include "caja-file-management-properties.h"
+
 /* string enum preferences */
 #define CAJA_FILE_MANAGEMENT_PROPERTIES_DEFAULT_VIEW_WIDGET "default_view_combobox"
 #define CAJA_FILE_MANAGEMENT_PROPERTIES_ICON_VIEW_ZOOM_WIDGET "icon_view_zoom_combobox"
@@ -74,6 +73,7 @@
 #define CAJA_FILE_MANAGEMENT_PROPERTIES_MEDIA_AUTOMOUNT_OPEN "media_automount_open_checkbutton"
 #define CAJA_FILE_MANAGEMENT_PROPERTIES_MEDIA_AUTORUN_NEVER "media_autorun_never_checkbutton"
 #define CAJA_FILE_MANAGEMENT_PROPERTIES_USE_IEC_UNITS_WIDGET "use_iec_units"
+#define CAJA_FILE_MANAGEMENT_PROPERTIES_SHOW_ICONS_IN_LIST_VIEW "show_icons_in_list_view"
 
 /* int enums */
 #define CAJA_FILE_MANAGEMENT_PROPERTIES_THUMBNAIL_LIMIT_WIDGET "preview_image_size_combobox"
@@ -204,13 +204,14 @@ caja_file_management_properties_size_group_create (GtkBuilder *builder,
 {
     GtkSizeGroup *size_group;
     int i;
-    char *item_name;
-    GtkWidget *widget;
+    GtkWidget *widget = NULL;
 
     size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
     for (i = 0; i < items; i++)
     {
+        char *item_name;
+
         item_name = g_strdup_printf ("%s_%d", prefix, i);
         widget = GTK_WIDGET (gtk_builder_get_object (builder, item_name));
         gtk_size_group_add_widget (size_group, widget);
@@ -225,7 +226,6 @@ preferences_show_help (GtkWindow *parent,
                        char const *sect_id)
 {
     GError *error = NULL;
-    GtkWidget *dialog;
     char *help_string;
 
     g_assert (helpfile != NULL);
@@ -240,6 +240,8 @@ preferences_show_help (GtkWindow *parent,
 
     if (error)
     {
+        GtkWidget *dialog;
+
         dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
                                          GTK_DIALOG_DESTROY_WITH_PARENT,
                                          GTK_MESSAGE_ERROR,
@@ -262,10 +264,10 @@ caja_file_management_properties_dialog_response_cb (GtkDialog *parent,
         int response_id,
         GtkBuilder *builder)
 {
-    char *section;
-
     if (response_id == GTK_RESPONSE_HELP)
     {
+        char *section;
+
         switch (gtk_notebook_get_current_page (GTK_NOTEBOOK (gtk_builder_get_object (builder, "notebook1"))))
         {
         default:
@@ -511,27 +513,27 @@ create_date_format_menu (GtkBuilder *builder)
 {
     GtkComboBoxText *combo_box;
     gchar *date_string;
-    time_t now_raw;
-    struct tm* now;
+    GDateTime *now;
 
     combo_box = GTK_COMBO_BOX_TEXT
             (gtk_builder_get_object (builder,
                                      CAJA_FILE_MANAGEMENT_PROPERTIES_DATE_FORMAT_WIDGET));
 
-    now_raw = time (NULL);
-    now = localtime (&now_raw);
+    now = g_date_time_new_now_local ();
 
-    date_string = eel_strdup_strftime ("%c", now);
+    date_string = g_date_time_format (now, "%c");
     gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo_box), date_string);
     g_free (date_string);
 
-    date_string = eel_strdup_strftime ("%Y-%m-%d %H:%M:%S", now);
+    date_string = g_date_time_format (now, "%Y-%m-%d %H:%M:%S");
     gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo_box), date_string);
     g_free (date_string);
 
-    date_string = eel_strdup_strftime (_("today at %-I:%M:%S %p"), now);
+    date_string = g_date_time_format (now, _("today at %-I:%M:%S %p"));
     gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo_box), date_string);
     g_free (date_string);
+
+    g_date_time_unref (now);
 }
 
 static void
@@ -729,22 +731,22 @@ extension_state_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer
 	GtkTreeModel *model;
     gboolean new_state;
     Extension *ext;
-    
+
 	path = gtk_tree_path_new_from_string (path_str);
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (data));
-    
+
     g_object_get (G_OBJECT (cell), "active", &new_state, NULL);
     gtk_tree_model_get_iter_from_string (model, &iter, path_str);
-    
+
     new_state ^= 1;
 
 	if (&iter != NULL)
     {
         gtk_tree_model_get (model, &iter, EXT_STRUCT_COLUMN, &ext, -1);
-        
+
         if (caja_extension_set_state (ext, new_state))
         {
-            gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
+            gtk_list_store_set (GTK_LIST_STORE (model), &iter,
                                 EXT_STATE_COLUMN, new_state, -1);
         }
     }
@@ -875,7 +877,7 @@ caja_file_management_properties_dialog_setup_extension_page (GtkBuilder *builder
     cairo_surface_t *ext_surface_icon;
     GtkButton *about_button, *configure_button;
     gchar *ext_text_info;
-    
+
     GList *extensions;
     int i;
 
@@ -885,16 +887,16 @@ caja_file_management_properties_dialog_setup_extension_page (GtkBuilder *builder
                     gtk_builder_get_object (builder, "extension_view"));
     store = GTK_LIST_STORE (
                     gtk_builder_get_object (builder, "extension_store"));
-                    
+
     toggle = GTK_CELL_RENDERER_TOGGLE (
                     gtk_builder_get_object (builder, "extension_toggle"));
     g_object_set (toggle, "xpad", 6, NULL);
-                    
+
     g_signal_connect (toggle, "toggled",
                       G_CALLBACK (extension_state_toggled), view);
-    
+
     icon_theme = gtk_icon_theme_get_default();
-    
+
     for (i = 0; i < g_list_length (extensions); i++)
     {
         Extension* ext = EXTENSION (g_list_nth_data (extensions, i));
@@ -1112,8 +1114,8 @@ bind_builder_radio (GtkBuilder *builder,
             const char *prefs,
             const char **values)
 {
-    GtkWidget *button;
     int i;
+    GtkWidget *button = NULL;
 
     for (i = 0; widget_names[i] != NULL; i++) {
         button = GTK_WIDGET (gtk_builder_get_object (builder, widget_names[i]));
@@ -1191,6 +1193,10 @@ caja_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow *wi
                        CAJA_FILE_MANAGEMENT_PROPERTIES_USE_IEC_UNITS_WIDGET,
                        CAJA_PREFERENCES_USE_IEC_UNITS);
 
+    bind_builder_bool (builder, caja_preferences,
+                       CAJA_FILE_MANAGEMENT_PROPERTIES_SHOW_ICONS_IN_LIST_VIEW,
+                       CAJA_PREFERENCES_SHOW_ICONS_IN_LIST_VIEW);
+
     bind_builder_enum (builder, caja_preferences,
                        CAJA_FILE_MANAGEMENT_PROPERTIES_DEFAULT_VIEW_WIDGET,
                        CAJA_PREFERENCES_DEFAULT_FOLDER_VIEWER,
@@ -1273,6 +1279,12 @@ caja_file_management_properties_dialog_setup (GtkBuilder *builder, GtkWindow *wi
         gtk_window_set_screen (GTK_WINDOW (dialog), gtk_window_get_screen(window));
     }
 
+    GtkWidget *notebook = GTK_WIDGET (gtk_builder_get_object (builder, "notebook1"));
+    gtk_widget_add_events (GTK_WIDGET (notebook), GDK_SCROLL_MASK);
+    g_signal_connect (GTK_WIDGET (notebook), "scroll-event",
+                      G_CALLBACK (eel_dialog_page_scroll_event_callback),
+                      window);
+
     gtk_widget_show (dialog);
 }
 
