@@ -22,14 +22,16 @@
  */
 
 #include <config.h>
-#include "caja-side-pane.h"
+
+#include <gdk/gdkkeysyms.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
+
+#include "caja-side-pane.h"
 
 typedef struct
 {
@@ -51,8 +53,6 @@ struct _CajaSidePanePrivate
     GList *panels;
 };
 
-static void caja_side_pane_class_init (CajaSidePaneClass *klass);
-static void caja_side_pane_init       (CajaSidePane *side_pane);
 static void caja_side_pane_dispose    (GObject *object);
 static void caja_side_pane_finalize   (GObject *object);
 
@@ -71,7 +71,7 @@ static SidePanel *
 panel_for_widget (CajaSidePane *side_pane, GtkWidget *widget)
 {
     GList *l;
-    SidePanel *panel;
+    SidePanel *panel = NULL;
 
     for (l = side_pane->details->panels; l != NULL; l = l->next)
     {
@@ -134,10 +134,8 @@ static void
 caja_side_pane_class_init (CajaSidePaneClass *klass)
 {
     GObjectClass *gobject_class;
-    GtkWidgetClass *widget_class;
 
     gobject_class = G_OBJECT_CLASS (klass);
-    widget_class = GTK_WIDGET_CLASS (klass);
 
     gobject_class->finalize = caja_side_pane_finalize;
     gobject_class->dispose = caja_side_pane_dispose;
@@ -470,7 +468,6 @@ caja_side_pane_remove_panel (CajaSidePane *side_pane,
                              GtkWidget *widget)
 {
     SidePanel *panel;
-    int page_num;
 
     g_return_if_fail (side_pane != NULL);
     g_return_if_fail (CAJA_IS_SIDE_PANE (side_pane));
@@ -483,6 +480,8 @@ caja_side_pane_remove_panel (CajaSidePane *side_pane,
 
     if (panel)
     {
+        int page_num;
+
         page_num = gtk_notebook_page_num (GTK_NOTEBOOK (side_pane->details->notebook),
                                           widget);
         gtk_notebook_remove_page (GTK_NOTEBOOK (side_pane->details->notebook),
