@@ -26,8 +26,32 @@
 /* caja-window.c: Implementation of the main window object */
 
 #include <config.h>
-#include "caja-window-private.h"
 
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdkx.h>
+#include <gdk/gdkkeysyms.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+#ifdef HAVE_X11_XF86KEYSYM_H
+#include <X11/XF86keysym.h>
+#endif
+
+#include <eel/eel-debug.h>
+#include <eel/eel-gtk-macros.h>
+#include <eel/eel-string.h>
+
+#include <libcaja-private/caja-file-utilities.h>
+#include <libcaja-private/caja-file-attributes.h>
+#include <libcaja-private/caja-global-preferences.h>
+#include <libcaja-private/caja-metadata.h>
+#include <libcaja-private/caja-mime-actions.h>
+#include <libcaja-private/caja-program-choosing.h>
+#include <libcaja-private/caja-view-factory.h>
+#include <libcaja-private/caja-clipboard.h>
+#include <libcaja-private/caja-search-directory.h>
+#include <libcaja-private/caja-signaller.h>
+
+#include "caja-window-private.h"
 #include "caja-actions.h"
 #include "caja-application.h"
 #include "caja-bookmarks-window.h"
@@ -39,27 +63,6 @@
 #include "caja-search-bar.h"
 #include "caja-navigation-window-pane.h"
 #include "caja-src-marshal.h"
-#include <eel/eel-debug.h>
-#include <eel/eel-gtk-macros.h>
-#include <eel/eel-string.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gdk/gdkx.h>
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-#ifdef HAVE_X11_XF86KEYSYM_H
-#include <X11/XF86keysym.h>
-#endif
-#include <libcaja-private/caja-file-utilities.h>
-#include <libcaja-private/caja-file-attributes.h>
-#include <libcaja-private/caja-global-preferences.h>
-#include <libcaja-private/caja-metadata.h>
-#include <libcaja-private/caja-mime-actions.h>
-#include <libcaja-private/caja-program-choosing.h>
-#include <libcaja-private/caja-view-factory.h>
-#include <libcaja-private/caja-clipboard.h>
-#include <libcaja-private/caja-search-directory.h>
-#include <libcaja-private/caja-signaller.h>
 
 #define MAX_HISTORY_ITEMS 50
 
@@ -273,16 +276,17 @@ void
 caja_window_new_tab (CajaWindow *window)
 {
     CajaWindowSlot *current_slot;
-    CajaWindowSlot *new_slot;
     CajaWindowOpenFlags flags;
     GFile *location = NULL;
-    int new_slot_position;
-    char *scheme;
 
     current_slot = window->details->active_pane->active_slot;
     location = caja_window_slot_get_location (current_slot);
 
     if (location != NULL) {
+        CajaWindowSlot *new_slot;
+        int new_slot_position;
+        char *scheme;
+
     	flags = 0;
 
     	new_slot_position = g_settings_get_enum (caja_preferences, CAJA_PREFERENCES_NEW_TAB_POSITION);
@@ -304,6 +308,42 @@ caja_window_new_tab (CajaWindow *window)
     }
 }
 
+/*Opens a new window when called from an existing window and goes to the same location that's in the existing window.*/
+void
+caja_window_new_window (CajaWindow *window)
+{
+    CajaWindowSlot *current_slot;
+    GFile *location = NULL;
+    g_return_if_fail (CAJA_IS_WINDOW (window));
+
+    /*Get and set the directory location of current window (slot).*/
+    current_slot = window->details->active_pane->active_slot;
+    location = caja_window_slot_get_location (current_slot);
+
+    if (location != NULL) 
+    {
+        CajaWindow *new_window;
+        CajaWindowSlot *new_slot;
+        CajaWindowOpenFlags flags;
+        flags = FALSE;
+
+        /*Create a new window*/
+        new_window = caja_application_create_navigation_window (
+                     window->application,
+        gtk_window_get_screen (GTK_WINDOW (window)));
+
+        /*Create a slot in the new window.*/
+        new_slot = new_window->details->active_pane->active_slot;
+        g_return_if_fail (CAJA_IS_WINDOW_SLOT (new_slot));
+
+        /*Open a directory at the set location in the new window (slot).*/
+        caja_window_slot_open_location_full (new_slot, location,
+                                             CAJA_WINDOW_OPEN_ACCORDING_TO_MODE,
+                                             flags, NULL, NULL, NULL);
+        g_object_unref (location);
+    }
+}
+
 void
 caja_window_go_up (CajaWindow *window, gboolean close_behind, gboolean new_tab)
 {
@@ -359,12 +399,14 @@ real_set_allow_up (CajaWindow *window,
 
     g_assert (CAJA_IS_WINDOW (window));
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (window->details->main_action_group,
                                           CAJA_ACTION_UP);
     gtk_action_set_sensitive (action, allow);
     action = gtk_action_group_get_action (window->details->main_action_group,
                                           CAJA_ACTION_UP_ACCEL);
     gtk_action_set_sensitive (action, allow);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 void
@@ -380,7 +422,6 @@ static void
 update_cursor (CajaWindow *window)
 {
     CajaWindowSlot *slot;
-    GdkCursor *cursor;
 
     slot = window->details->active_pane->active_slot;
 
@@ -409,16 +450,20 @@ caja_window_sync_allow_stop (CajaWindow *window,
 
     g_assert (CAJA_IS_WINDOW (window));
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (window->details->main_action_group,
                                           CAJA_ACTION_STOP);
     allow_stop = gtk_action_get_sensitive (action);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     if (slot != window->details->active_pane->active_slot ||
             allow_stop != slot->allow_stop)
     {
         if (slot == window->details->active_pane->active_slot)
         {
+            G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
             gtk_action_set_sensitive (action, slot->allow_stop);
+            G_GNUC_END_IGNORE_DEPRECATIONS;
         }
 
         if (gtk_widget_get_realized (GTK_WIDGET (window)))
@@ -438,9 +483,11 @@ caja_window_allow_reload (CajaWindow *window, gboolean allow)
 
     g_return_if_fail (CAJA_IS_WINDOW (window));
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (window->details->main_action_group,
                                           CAJA_ACTION_RELOAD);
     gtk_action_set_sensitive (action, allow);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 void
@@ -981,46 +1028,6 @@ caja_window_slot_close (CajaWindowSlot *slot)
     caja_window_pane_slot_close (slot->pane, slot);
 }
 
-static void
-caja_window_size_request (GtkWidget		*widget,
-                          GtkRequisition	*requisition)
-{
-    GdkScreen *screen;
-    guint max_width;
-    guint max_height;
-
-    g_assert (CAJA_IS_WINDOW (widget));
-    g_assert (requisition != NULL);
-
-    screen = gtk_window_get_screen (GTK_WINDOW (widget));
-
-    /* Limit the requisition to be within 90% of the available screen
-     * real state.
-     *
-     * This way the user will have a fighting chance of getting
-     * control of their window back if for whatever reason one of the
-     * window's descendants decide they want to be 4000 pixels wide.
-     *
-     * Note that the user can still make the window really huge by hand.
-     *
-     * Bugs in components or other widgets that cause such huge geometries
-     * to be requested, should still be fixed.  This code is here only to
-     * prevent the extremely frustrating consequence of such bugs.
-     */
-    max_width = get_max_forced_width (screen);
-    max_height = get_max_forced_height (screen);
-
-    if (requisition->width > (int) max_width)
-    {
-        requisition->width = max_width;
-    }
-
-    if (requisition->height > (int) max_height)
-    {
-        requisition->height = max_height;
-    }
-}
-
 static void
 caja_window_realize (GtkWidget *widget)
 {
@@ -1052,6 +1059,7 @@ caja_window_key_press_event (GtkWidget *widget,
             action = NULL;
 
             action_groups = gtk_ui_manager_get_action_groups (window->details->ui_manager);
+            G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
             while (action_groups != NULL && action == NULL)
             {
                 action = gtk_action_group_get_action (action_groups->data, extra_window_keybindings[i].action);
@@ -1064,6 +1072,7 @@ caja_window_key_press_event (GtkWidget *widget,
                 gtk_action_activate (action);
                 return TRUE;
             }
+            G_GNUC_END_IGNORE_DEPRECATIONS;
 
             break;
         }
@@ -1093,16 +1102,19 @@ action_view_as_callback (GtkAction *action,
                          ActivateViewData *data)
 {
     CajaWindow *window;
-    CajaWindowSlot *slot;
 
     window = data->window;
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
     {
+        CajaWindowSlot *slot;
+
         slot = window->details->active_pane->active_slot;
         caja_window_slot_set_content_view (slot,
                                            data->id);
     }
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 static GtkRadioAction *
@@ -1117,21 +1129,23 @@ add_view_as_menu_item (CajaWindow *window,
     char action_name[32];
     ActivateViewData *data;
 
-    char accel[32];
-    char accel_path[48];
-    unsigned int accel_keyval;
-
     info = caja_view_factory_lookup (identifier);
 
     g_snprintf (action_name, sizeof (action_name), "view_as_%d", index);
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_radio_action_new (action_name,
                                    _(info->view_menu_label_with_mnemonic),
                                    _(info->display_location_label),
                                    NULL,
                                    0);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     if (index >= 1 && index <= 9)
     {
+        char accel[32];
+        char accel_path[48];
+        unsigned int accel_keyval;
+
         g_snprintf (accel, sizeof (accel), "%d", index);
         g_snprintf (accel_path, sizeof (accel_path), "<Caja-Window>/%s", action_name);
 
@@ -1139,13 +1153,17 @@ add_view_as_menu_item (CajaWindow *window,
 		g_assert (accel_keyval != GDK_KEY_VoidSymbol);
 
         gtk_accel_map_add_entry (accel_path, accel_keyval, GDK_CONTROL_MASK);
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
         gtk_action_set_accel_path (GTK_ACTION (action), accel_path);
+        G_GNUC_END_IGNORE_DEPRECATIONS;
     }
 
     if (window->details->view_as_radio_action != NULL)
     {
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
         gtk_radio_action_set_group (action,
                                     gtk_radio_action_get_group (window->details->view_as_radio_action));
+        G_GNUC_END_IGNORE_DEPRECATIONS;
     }
     else if (index != 0)
     {
@@ -1161,9 +1179,11 @@ add_view_as_menu_item (CajaWindow *window,
                            G_CALLBACK (action_view_as_callback),
                            data, (GClosureNotify) free_activate_view_data, 0);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     gtk_action_group_add_action (window->details->view_as_action_group,
                                  GTK_ACTION (action));
     g_object_unref (action);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     gtk_ui_manager_add_ui (window->details->ui_manager,
                            merge_id,
@@ -1213,12 +1233,14 @@ update_extra_viewer_in_view_as_menus (CajaWindow *window,
         window->details->extra_viewer_merge_id = 0;
     }
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     if (window->details->extra_viewer_radio_action != NULL)
     {
         gtk_action_group_remove_action (window->details->view_as_action_group,
                                         GTK_ACTION (window->details->extra_viewer_radio_action));
         window->details->extra_viewer_radio_action = NULL;
     }
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     if (id != NULL)
     {
@@ -1296,8 +1318,10 @@ caja_window_synch_view_as_menus (CajaWindow *window)
     }
 
     g_snprintf (action_name, sizeof (action_name), "view_as_%d", index);
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (window->details->view_as_action_group,
                                           action_name);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     /* Don't trigger the action callback when we're synchronizing */
     g_signal_handlers_block_matched (action,
@@ -1306,7 +1330,9 @@ caja_window_synch_view_as_menus (CajaWindow *window)
                                      NULL,
                                      action_view_as_callback,
                                      NULL);
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
     g_signal_handlers_unblock_matched (action,
                                        G_SIGNAL_MATCH_FUNC,
                                        0, 0,
@@ -1340,7 +1366,6 @@ static void
 load_view_as_menu (CajaWindow *window)
 {
     GList *node;
-    int index;
     guint merge_id;
 
     if (window->details->short_list_merge_id != 0)
@@ -1368,22 +1393,27 @@ load_view_as_menu (CajaWindow *window)
 
     merge_id = gtk_ui_manager_new_merge_id (window->details->ui_manager);
     window->details->short_list_merge_id = merge_id;
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     window->details->view_as_action_group = gtk_action_group_new ("ViewAsGroup");
     gtk_action_group_set_translation_domain (window->details->view_as_action_group, GETTEXT_PACKAGE);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
     window->details->view_as_radio_action = NULL;
 
-    /* Add a menu item for each view in the preferred list for this location. */
-    /* Start on 1, because extra_viewer gets index 0 */
-    for (node = window->details->short_list_viewers, index = 1;
-            node != NULL;
-            node = node->next, ++index)
-    {
-        /* Menu item in View menu. */
-        add_view_as_menu_item (window,
-                               CAJA_MENU_PATH_SHORT_LIST_PLACEHOLDER,
-                               node->data,
-                               index,
-                               merge_id);
+    if (g_list_length (window->details->short_list_viewers) > 1) {
+        int index;
+        /* Add a menu item for each view in the preferred list for this location. */
+        /* Start on 1, because extra_viewer gets index 0 */
+        for (node = window->details->short_list_viewers, index = 1;
+                node != NULL;
+                node = node->next, ++index)
+        {
+            /* Menu item in View menu. */
+            add_view_as_menu_item (window,
+                    CAJA_MENU_PATH_SHORT_LIST_PLACEHOLDER,
+                    node->data,
+                    index,
+                    merge_id);
+        }
     }
     gtk_ui_manager_insert_action_group (window->details->ui_manager,
                                         window->details->view_as_action_group,
@@ -1463,10 +1493,10 @@ static void
 real_sync_title (CajaWindow *window,
                  CajaWindowSlot *slot)
 {
-    char *copy;
-
     if (slot == window->details->active_pane->active_slot)
     {
+        char *copy;
+
         copy = g_strdup (slot->title);
         g_signal_emit_by_name (window, "title_changed",
                                slot->title);
@@ -1514,6 +1544,7 @@ caja_window_sync_zoom_widgets (CajaWindow *window)
         can_zoom_out = FALSE;
     }
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (window->details->main_action_group,
                                           CAJA_ACTION_ZOOM_IN);
     gtk_action_set_visible (action, supports_zooming);
@@ -1528,6 +1559,7 @@ caja_window_sync_zoom_widgets (CajaWindow *window)
                                           CAJA_ACTION_ZOOM_NORMAL);
     gtk_action_set_visible (action, supports_zooming);
     gtk_action_set_sensitive (action, can_zoom);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     g_signal_emit (window, signals[ZOOM_CHANGED], 0,
                    zoom_level, supports_zooming, can_zoom,
@@ -1656,7 +1688,6 @@ void
 caja_window_slot_set_viewed_file (CajaWindowSlot *slot,
                                   CajaFile *file)
 {
-    CajaWindow *window;
     CajaFileAttributes attributes;
 
     if (slot->viewed_file == file)
@@ -1670,6 +1701,8 @@ caja_window_slot_set_viewed_file (CajaWindowSlot *slot,
 
     if (slot->viewed_file != NULL)
     {
+        CajaWindow *window;
+
         window = slot->pane->window;
 
         if (CAJA_IS_SPATIAL_WINDOW (window))
@@ -1740,7 +1773,6 @@ caja_add_bookmark_to_history_list (CajaBookmark *bookmark)
      * this is not a CajaNavigationWindow function. Perhaps it belongs
      * in its own file.
      */
-    int i;
     GList *l, *next;
     static gboolean free_history_list_is_set_up;
 
@@ -1759,6 +1791,8 @@ caja_add_bookmark_to_history_list (CajaBookmark *bookmark)
     if (!history_list ||
             caja_bookmark_compare_uris (history_list->data, bookmark))
     {
+        int i;
+
         g_object_ref (bookmark);
         remove_from_history_list (bookmark);
         history_list = g_list_prepend (history_list, bookmark);
@@ -1917,7 +1951,7 @@ caja_get_history_list (void)
 static GList *
 caja_window_get_history (CajaWindow *window)
 {
-    return eel_g_object_list_copy (history_list);
+    return g_list_copy_deep (history_list, (GCopyFunc) g_object_ref, NULL);
 }
 
 
@@ -2093,7 +2127,7 @@ caja_window_info_iface_init (CajaWindowInfoIface *iface)
     iface->get_selection = caja_window_get_selection;
     iface->get_hidden_files_mode = caja_window_get_hidden_files_mode;
     iface->set_hidden_files_mode = caja_window_set_hidden_files_mode;
-    
+
     iface->get_backup_files_mode = caja_window_get_backup_files_mode;
     iface->set_backup_files_mode = caja_window_set_backup_files_mode;
 
